#
# spec file for package bcc
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libversion 0.1.8

Name:           bcc
Version:        0.1.8
Release:        3.2
Summary:        BPF Compiler Collection (BCC)
License:        Apache-2.0
Group:          Development/Languages
Url:            https://github.com/iovisor/bcc
Source:         https://github.com/iovisor/bcc/archive/v%{version}.tar.gz
Patch1:         bcc-kernel-header-search.patch
ExclusiveArch:  x86_64
BuildRequires:  bison
BuildRequires:  cmake >= 2.8.7
BuildRequires:  flex
BuildRequires:  llvm-clang-devel >= 3.7.0
BuildRequires:  llvm-devel >= 3.7.0
BuildRequires:  libstdc++-devel
BuildRequires:  pkg-config
BuildRequires:  python-devel
BuildRequires:  python-setuptools
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools

%description
BCC is a toolkit for creating efficient kernel tracing and manipulation
programs, and includes several useful tools and examples. It makes use
of eBPF (Extended Berkeley Packet Filters), a new feature that was first
added to Linux 3.15. Much of what BCC uses requires Linux 4.1 and above.

%package -n libbcc0
Summary:        Shared Library for BPF Compiler Collection
Group:          System/Libraries

%description -n libbcc0
Shared Library for BPF Compiler Collection (BCC)

%package devel
Summary:        BPF Compiler Collection (BCC) (devel package)
Group:          Development/Languages
Requires:       libbcc0 = %{version}

%description devel
Shared library and pkg-config for developing BCC programs

%package -n python-bcc
Summary:        Python bindings for BPF Compiler Collection
Group:          Development/Languages
Requires:       kernel >= 4.1.0
Requires:       kernel-devel >= 4.1.0
Requires:       libbcc0 = %{version}

%description -n python-bcc
Python bindings for BPF Compiler Collection (BCC)

%package -n python3-bcc
Summary:        Python3 bindings for BPF Compiler Collection
Group:          Development/Languages
Requires:       kernel >= 4.1.0
Requires:       kernel-devel >= 4.1.0
Requires:       libbcc0 = %{version}

%description -n python3-bcc
Python3 bindings for BPF Compiler Collection (BCC)

%package examples
Summary:        Examples for BPF Compiler Collection (BCC)
Group:          Development/Languages
Requires:       python-bcc = %{version}
Requires:       python-future
Recommends:     python-pyroute2
Recommends:     python-netaddr
Recommends:     netperf

%description examples
Python and C examples for BPF Compiler Collection (BCC)

%package tools
Summary:        Tracing tools of BPF Compiler Collection (BCC)
Group:          Development/Languages
Requires:       python-bcc = %{version}
Requires:       python-future

%description tools
Python tracing scripts of BPF Compiler Collection (BCC)

%prep
%setup -D -n %{name}-%{version}
%patch1 -p1

%build
export LD_LIBRARY_PATH="%{_builddir}/usr/lib64"
export PATH="%{_builddir}/usr/bin":$PATH

# To work around the c++11 tag support (bsc#935533)
export CC=/usr/bin/clang
export CXX=/usr/bin/clang++

mkdir build
pushd build
CFLAGS=$RPM_OPT_FLAGS CXXFLAGS=$RPM_OPT_FLAGS cmake \
	-DREVISION_LAST=%{libversion} \
	-DREVISION=%{libversion} \
	-DCMAKE_INSTALL_PREFIX=/usr \
	-DBCC_KERNEL_HAS_SOURCE_DIR=1 \
	..
make %{?_smp_mflags} VERBOSE=1
popd

%install
pushd build
make install DESTDIR=%{buildroot}
# For python3-bcc
cmake -DPYTHON_CMD=python3 ..
pushd src/python/
make %{?_smp_mflags} VERBOSE=1
make install DESTDIR=%{buildroot}
popd
popd

%post -n libbcc0 -p /sbin/ldconfig

%postun -n libbcc0 -p /sbin/ldconfig

%files -n bcc-devel
%{_libdir}/libbcc.so
%dir %{_includedir}/bcc/
%{_includedir}/bcc/*
%{_libdir}/pkgconfig/libbcc.pc

%files -n libbcc0
%{_libdir}/libbcc.so.*

%files -n python-bcc
%{python_sitelib}/bcc*

%files -n python3-bcc
%{python3_sitelib}/bcc*

%files examples
%dir %{_datadir}/bcc/
%dir %{_datadir}/bcc/examples/
%{_datadir}/bcc/examples/*

%files tools
%dir %{_datadir}/bcc/
%dir %{_datadir}/bcc/tools/
%{_datadir}/bcc/tools/*
%dir %{_datadir}/bcc/man/
%{_datadir}/bcc/man/*

%changelog
* Fri Aug  5 2016 glin@suse.com
- Amend the spec file for bsc#990170
  + Use the upstream tarball and add the URL
  + Amend the description of the pacakge
  + Use the right group for libbcc0
* Wed Apr 20 2016 glin@suse.com
- Remove "strip" from "make install" to enable debuginfo
  (fate#320644)
* Tue Mar 15 2016 glin@suse.com
- Switch to clang to avoid the c++11 tag issue (bsc#935533)
- Update bcc-kernel-header-search.patch to include headers in
  /lib/modules/$(uname -r)/build/
* Tue Mar  8 2016 glin@suse.com
- Replace bcc-suse-kernel-headers.patch with the upstream fix,
  bcc-kernel-header-search.patch, and add
  "-DBCC_KERNEL_HAS_SOURCE_DIR=1" to cmake.
- Fix the formation in the spec file
* Thu Feb 25 2016 glin@suse.com
- Update to version 0.1.8
  + http_filter renamed, README fixed
  + Migrated filelife to bpf_perf_event
  + migrated to use bpf_perf_events
  + Migrated killsnoop to bpf_perf_event
  + Print traceback only if verbose mode was requested
  + trace: trace function execution with custom format strings and
    filters
- Add back python3-bcc
- Make python-bcc require libbcc0
* Thu Feb 18 2016 glin@suse.com
- Update to version 0.1.7+git1455766673.13e74d3
  + use __builtin_memcpy() instead of unrolled loop
  + http filter example
  + Add bpf_module.h to CMakeLists.txt
  + different man formats
  + Fix segfault in ~BPFModule on syntax error
  + Add bitesize tool
  + Support array and pointer types in scanf generated function
  + Add biotop tool
  + Added memory leak tracer
  + Fix python map.items() racing with bpf delete
  + Don't show allocations newer than a configurable age
  + Add bpf_get_prandom_u32 to helpers
  + Added --stack-depth switch to control the number of stack
    frames captured for each allocation
  + Fixed long arg name from stack_depth to stack-depth
  + Added option to display only top N stacks by size
  + use bpf_perf_event_output() instead
  + save one bpf_probe_read()
  + 3 tools: oomkill, dcstat, dcsnoop
  + Implemented histogram functionality, including strings; added
    examples
  + Added ret probes
  + Renamed to argdist.py, updated command-line switches, added
    kernel probe pid filtering, added verbose mode that prints the
    BPF program
  + ext4 and xfs tools
  + tcp to bpf_perf_output
  + 3 tools: tcpretrans, zfsslower, zfsdist
  + inline C in /tools
  + 2 tools: btrfsdist, btrfsslower
  + Split bcc/__init__.py into multiple files
  + Split bcc.table.BPFTable into multiple type-specific classes
  + Support native integer indexing in table.Array type
  + Fix breakage in open_perf_buffer
  + Embed runtime header files in libbcc.so
- Add bcc-suse-kernel-headers.patch to fix the kernel header path
- Drop bcc-workaround-gcc5-abi.patch since it never works...
- Drop the dependency of bcc-devel from python-bcc
* Tue Feb  2 2016 glin@suse.com
- Update to version v0.1.7+git20160131.143df80
  + Updates to use cmake GLOB and libbcc.so.0 in python init
  + Add decode() to ascii string in offcputime.py
  + Add libbpf.c support for uprobes
  + Add python support for attaching bpf programs to uprobes
  + Fixes for address calculation
  + Fixup objdump calling syntax and add docstrings
  + Add uprobe strlen histogram example
  + Update test_dump_func to be python3 compatible
* Tue Jan 26 2016 glin@suse.com
- Update to version v0.1.7+git20160119.f50ca1f
  + fix pep8 lint errors in the rest of the tools
  + Close fd and unshare when public map is destructed
  + stack walker typo and improvement
  + optimize code, remove unnecessary filter check
  + add -u, and change from 2 to 1 traced funcitons
* Mon Jan 11 2016 glin@suse.com
- Update to version v0.1.7+git20160110.a0aa7f2
  + Remove runtime dependency on gcc stdarg headers and make
  + Add ability to set custom cflags when loading programs
  + Add ability to export maps, enables cross-program sharing
  + Rename BPF_EXPORT to BPF_TABLE_PUBLIC
  + fix pep8 lint errors in biolatency and biosnoop
- Remove make from Requires of python-bcc
* Wed Dec 16 2015 glin@suse.com
- Update to version v0.1.7+git20151210.23b87e5:
  + Fixup dependencies of bcc-tools package
  + Automatically bump memlock ulimit
  + fixed bugs in control-flow generation
  + Fix breakage from LLVM 3.8 API change
  + make sure LDFLAGS are propagated as well
  + Improve json type support for misc struct/union types
  + Drop broken p4/docs symlink and create README.md+URL
- Drop upstreamed bcc-honor-external-cflags.patch
* Mon Nov 30 2015 glin@suse.com
- Udpate to bcc-0.1.7+git48.g1c7debd
- Add python-future as the Recommends for bcc-examples so that
  the scripts can be compatible with python 2 and python 3.
- Remove python3-bcc
* Mon Nov 16 2015 glin@suse.com
- Update to bcc-0.1.7+git34.gfa9684d
- Add bcc-workaround-gcc5-abi.patch to work around the old c++11
  abi in clang
- Add bcc-honor-external-cflags.patch to adopt the external cflags
- Drop bcc-fix-packaging.patch which is already in the tarball
- Amend the requirements of python-bcc
  + make and kernel-devel are necessary
- Add python3-bcc since the python binding is compatiable with both
  2 and 3
* Fri Oct 23 2015 glin@suse.com
- initial import: v0.1.7
- Add bcc-fix-packaging.patch to fix versioning issue of the shared
  library
